summaryrefslogtreecommitdiffstats
path: root/client/config
diff options
context:
space:
mode:
authorSlávek Banko <[email protected]>2016-04-08 03:07:15 +0200
committerSlávek Banko <[email protected]>2016-04-08 03:07:15 +0200
commit8f61d29f9c7b9387d5bfe5d269273650d9089b96 (patch)
tree142ab970d9b04ec5c94e14398319c69748a37e2a /client/config
parent96603e8acb744f86139b900e45d030ad684b6a4d (diff)
downloadtde-style-domino-8f61d29f9c7b9387d5bfe5d269273650d9089b96.tar.gz
tde-style-domino-8f61d29f9c7b9387d5bfe5d269273650d9089b96.zip
Initial TDE conversion
Signed-off-by: Slávek Banko <[email protected]>
Diffstat (limited to 'client/config')
-rw-r--r--client/config/Makefile.am8
-rw-r--r--client/config/config.cpp28
-rw-r--r--client/config/config.h10
3 files changed, 23 insertions, 23 deletions
diff --git a/client/config/Makefile.am b/client/config/Makefile.am
index d33a23e..b37477f 100644
--- a/client/config/Makefile.am
+++ b/client/config/Makefile.am
@@ -1,10 +1,10 @@
INCLUDES = $(all_includes)
-kde_module_LTLIBRARIES = kwin_domino_config.la
+kde_module_LTLIBRARIES = twin_domino_config.la
-kwin_domino_config_la_SOURCES = config.cpp
-kwin_domino_config_la_LDFLAGS = $(all_libraries) $(KDE_PLUGIN) -module
-kwin_domino_config_la_LIBADD = $(LIB_KDEUI) $(LIB_QT) $(LIB_KDECORE)
+twin_domino_config_la_SOURCES = config.cpp
+twin_domino_config_la_LDFLAGS = $(all_libraries) $(KDE_PLUGIN) -module
+twin_domino_config_la_LIBADD = $(LIB_TDEUI) $(LIB_QT) $(LIB_TDECORE)
METASOURCES = AUTO
noinst_HEADERS = config.h
diff --git a/client/config/config.h b/client/config/config.h
index fbe5494..e48e96e 100644
--- a/client/config/config.h
+++ b/client/config/config.h
@@ -24,7 +24,7 @@
#define DOMINOCONFIG_H
#include <tqcheckbox.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <tqvbox.h>
#include <kcolorbutton.h>
@@ -33,7 +33,7 @@ class DominoConfig: public TQObject
Q_OBJECT
public:
- DominoConfig( KConfig* config, TQWidget* parent );
+ DominoConfig( TDEConfig* config, TQWidget* parent );
~DominoConfig();
// These public signals/slots work similar to KCM modules
@@ -41,15 +41,15 @@ class DominoConfig: public TQObject
void changed();
public slots:
- void load(KConfig* config);
- void save(KConfig* config);
+ void load(TDEConfig* config);
+ void save(TDEConfig* config);
void defaults();
protected slots:
void slotSelectionChanged(); // Internal use
void loadButtonContourColors();
private:
- KConfig* conf;
+ TDEConfig* conf;
TQVBox* vBox;
TQCheckBox* customBorderColor;
KColorButton* borderColor;
diff --git a/client/config/config.cpp b/client/config/config.cpp
index 482c1df..5dfffb2 100644
--- a/client/config/config.cpp
+++ b/client/config/config.cpp
@@ -21,8 +21,8 @@
*/
#include "config.h"
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
#include <tqvbox.h>
#include <tqlayout.h>
#include <tqlabel.h>
@@ -31,24 +31,24 @@
extern "C"
{
- KDE_EXPORT TQObject* allocate_config( KConfig* config, TQWidget* parent )
+ KDE_EXPORT TQObject* allocate_config( TDEConfig* config, TQWidget* parent )
{
return(new DominoConfig(config, parent));
}
}
// NOTE:
// 'config' is a pointer to the kwindecoration modules open kwin config,
// and is by default set to the "Style" group.
// 'parent' is the parent of the TQObject, which is a VBox inside the
-// Configure tab in kwindecoration
+// Configure tab in twindecoration
-DominoConfig::DominoConfig( KConfig* config, TQWidget* parent )
+DominoConfig::DominoConfig( TDEConfig* config, TQWidget* parent )
: TQObject( parent )
{
- conf = new KConfig("kwindominorc");
+ conf = new TDEConfig("twindominorc");
- KGlobal::locale()->insertCatalogue("kwin_clients");
+ TDEGlobal::locale()->insertCatalogue("twin_clients");
vBox = new TQVBox( parent );
@@ -162,7 +162,7 @@ DominoConfig::DominoConfig( KConfig* config, TQWidget* parent )
connect(buttonPressedContourColor, SIGNAL(changed(const TQColor&)), this, SLOT(slotSelectionChanged()));
- // Make the widgets visible in kwindecoration valueChanged
+ // Make the widgets visible in twindecoration valueChanged
vBox->show();
}
@@ -180,9 +180,9 @@ void DominoConfig::slotSelectionChanged()
}
-// Loads the configurable options from the kwinrc config file
-// It is passed the open config from kwindecoration to improve efficiency
-void DominoConfig::load(KConfig*)
+// Loads the configurable options from the twinrc config file
+// It is passed the open config from twindecoration to improve efficiency
+void DominoConfig::load(TDEConfig*)
{
conf->setGroup("General");
@@ -213,8 +213,8 @@ void DominoConfig::load(KConfig*)
}
-// Saves the configurable options to the kwinrc config file
-void DominoConfig::save(KConfig*)
+// Saves the configurable options to the twinrc config file
+void DominoConfig::save(TDEConfig*)
{
conf->setGroup("General");
@@ -31,24 +31,24 @@
}
// NOTE:
-// 'config' is a pointer to the kwindecoration modules open kwin config,
+// 'config' is a pointer to the twindecoration modules open twin config,
// and is by default set to the "Style" group.
// 'parent' is the parent of the TQObject, which is a VBox inside the